@@ -43,18 +43,28 @@ def proxy_view(request, url, requests_args=None):
         response.content,
         status=response.status_code)
 
-    # Certain response headers should NOT be just tunneled through.  These are
-    # they.  For more info, see:
-    # http://www.w3.org/Protocols/rfc2616/rfc2616-sec13.html#sec13.5.1
-    #
-    # Note that, although content-encoding is not listed among the hop-by-hop
-    # headers, it can cause trouble as well.  Just let the server set the value
-    # as it should be.
-    hop_by_hop = ['connection', 'keep-alive', 'proxy-authenticate',
-                  'proxy-authorization', 'te', 'trailers', 'transfer-encoding',
-                  'upgrade', 'content-encoding']
+    excluded_headers = set([
+        # Hop-by-hop headers
+        # ------------------
+        # Certain response headers should NOT be just tunneled through.  These
+        # are they.  For more info, see:
+        # http://www.w3.org/Protocols/rfc2616/rfc2616-sec13.html#sec13.5.1
+        'connection', 'keep-alive', 'proxy-authenticate', 
+        'proxy-authorization', 'te', 'trailers', 'transfer-encoding', 
+        'upgrade', 
+
+        # Although content-encoding is not listed among the hop-by-hop headers,
+        # it can cause trouble as well.  Just let the server set the value as
+        # it should be.
+        'content-encoding',
+
+        # Since the remote server may or may not have sent the content in the
+        # same encoding as Django will, let Django worry about what the length
+        # should be.
+        'content-length',
+    ])
     for key, value in response.headers.iteritems():
-        if key.lower() in hop_by_hop:
+        if key.lower() in excluded_headers:
             continue
         proxy_response[key] = value
 
